OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "غیر معرروف قسم کی فائل",
    "Invalid image" : "غلط تصویر",
    "today" : "آج",
    "yesterday" : "کل",
    "last month" : "پچھلے مہنیے",
    "last year" : "پچھلے سال",
    "seconds ago" : "سیکنڈز پہلے",
    "__language_name__" : "اردو",
    "Apps" : "ایپز",
    "Settings" : "سیٹینگز",
    "Log out" : "لاگ آؤٹ",
    "Email" : "email",
    "Sunday" : "اتوار",
    "Monday" : "سوموار",
    "Tuesday" : "منگل",
    "Wednesday" : "بدھ",
    "Thursday" : "جمعرات",
    "Friday" : "جمعہ",
    "Saturday" : "ہفتہ",
    "January" : "جنوری",
    "February" : "فرورئ",
    "March" : "مارچ",
    "April" : "اپریل",
    "May" : "مئی",
    "June" : "جون",
    "July" : "جولائی",
    "August" : "اگست",
    "September" : "ستمبر",
    "October" : "اکتوبر",
    "November" : "نومبر",
    "December" : "دسمبر",
    "Users" : "یوزرز"
},
"nplurals=2; plural=(n != 1);");
